@@ -17,18 +17,18 @@ render_exercise <- function(block, default_height) {
   }
 
   # Translate pec and sample code for things to work in the encoded format
-  dict <- c(`pre-exercise-code` = "pre_exercise_code",
-            `sample-code` = "sample",
-            solution = "solution",
-            sct = "sct",
-            hint = "hint")
-  names(els) <- dict[names(els)]
+  els <- rename(els, "pre-exercise-code", "pre_exercise_code")
+  els <- rename(els, "sample-code", "sample")
+
   encoded <- base64encode(charToRaw(toJSON(els)))
-  pre <- "<script src=\"https://cdn.datacamp.com/datacamp-light-1.0.0.min.js\"></script>\n"
-  patt <- "%s<div data-datacamp-exercise data-lang=\"%s\" data-height=\"%s\" data-encoded=\"true\">%s</div>"
-  return(sprintf(patt, pre, block$lang, height, encoded))
+  patt <- "<div data-datacamp-exercise data-height=\"%s\" data-encoded=\"true\">%s</div>"
+  return(sprintf(patt, height, encoded))
 }
 
-get_height <- function(chunk_height, default_height) {
-
+rename <- function(named_vec, from, to) {
+  x <- which(names(named_vec) == from)
+  if (length(x) > 0) {
+    names(named_vec)[x] <- to
+  }
+  return(named_vec)
 }
