@@ -1,6 +1,7 @@
-allowed_elements <- c("pre-exercise-code", "sample-code", "solution", "sct", "hint")
+allowed_elements <- c("language", "pre-exercise-code", "sample-code", "solution", "sct", "hint")
 required_elements <- c("sample-code")
 project_alias <- "DataCamp Light"
+cdn_path <- "datacamp-light-latest.min.js"
 
 cpaste <- function(x) {
   paste(x, collapse = "\n")
@@ -29,37 +30,3 @@ to_html <- function(x) {
   html <- gsub("^(.*?)\\s*$", "\\1", html)
   html
 }
-
-tutorial_accessors <- function() {
-  dc_data <- list()
-
-  get = function(name) {
-    if (missing(name)) {
-      dc_data
-    } else {
-      dc_data[[name]]
-    }
-  }
-
-  set = function(...) {
-    dots = list(...)
-    dc_data <<- merge(dots)
-    invisible(NULL)
-  }
-
-  clear = function() {
-    dc_data <<- list()
-    invisible(NULL)
-  }
-
-  merge = function(values) merge_list(dc_data, values)
-
-  list(get = get, set = set, clear = clear)
-}
-
-merge_list = function(x, y) {
-  x[names(y)] = y
-  x
-}
-
-tutorial <- tutorial_accessors()
